@@ -1,5 +1,5 @@
 # Gearman Perl front end
-# Copyright (C) 2009 Dennis Schoen
+# Copyright (C) 2009-2010 Dennis Schoen
 # All rights reserved.
 #
 # This library is free software; you can redistribute it and/or modify
@@ -8,8 +8,16 @@
 
 package Gearman::XS::Job;
 
+use strict;
+use warnings;
+
+our $VERSION= '0.10';
+
 use Gearman::XS;
 
+1;
+__END__
+
 =head1 NAME
 
 Gearman::XS::Job - Perl job for gearman using libgearman
@@ -29,11 +37,6 @@ Get the workload for a job.
 
 Get job handle.
 
-=head2 $job->status($numerator, $denominator)
-
-Send status information for a running job. Returns a standard gearman return
-value.
-
 =head2 $job->function_name()
 
 Get the function name associated with a job.
@@ -42,17 +45,35 @@ Get the function name associated with a job.
 
 Get the unique ID associated with a job.
 
-=head2 $job->data($data)
+=head2 $job->send_status($numerator, $denominator)
+
+Send status information for a running job. Returns a standard gearman return
+value.
+
+=head2 $job->send_data($data)
 
 Send data for a running job. Returns a standard gearman return value.
 
+=head2 $job->send_fail()
+
+Send fail status for a job. Returns a standard gearman return value.
+
+=head2 $job->send_complete($result)
+
+Send result and complete status for a job. Returns a standard gearman return
+value.
+
+=head2 $job->send_warning($warning)
+
+Send warning for a running job. Returns a standard gearman return value.
+
 =head1 BUGS
 
 Any in libgearman plus many others of my own.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2009 Dennis Schoen
+Copyright (C) 2009-2010 Dennis Schoen
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.9 or,
@@ -62,10 +83,13 @@ at your option, any later version of Perl 5 you may have available.
 
 This is free software. IT COMES WITHOUT WARRANTY OF ANY KIND.
 
-=head1 AUTHORS
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=head1 AUTHOR
 
 Dennis Schoen <dennis@blogma.de>
 
-=cut
-
-1;
\ No newline at end of file
+=cut
\ No newline at end of file
