@@ -1,5 +1,5 @@
 # Gearman Perl front end
-# Copyright (C) 2009 Dennis Schoen
+# Copyright (C) 2009-2010 Dennis Schoen
 # All rights reserved.
 #
 # This library is free software; you can redistribute it and/or modify
@@ -8,8 +8,16 @@
 
 package Gearman::XS::Task;
 
+use strict;
+use warnings;
+
+our $VERSION= '0.10';
+
 use Gearman::XS;
 
+1;
+__END__
+
 =head1 NAME
 
 Gearman::XS::Task - Perl task for gearman using libgearman
@@ -33,7 +41,7 @@ Get data being returned for a task.
 
 Get data size being returned for a task.
 
-=head2 $task->function()
+=head2 $task->function_name()
 
 Get function name associated with a task.
 
@@ -45,13 +53,27 @@ Get the numerator of percentage complete for a task.
 
 Get the denominator of percentage complete for a task.
 
+=head2 $task->unique()
+
+Get unique identifier for a task.
+
+=head2 $task->is_known()
+
+Get status on whether a task is known or not. Returns 1 if known, empty string
+if not.
+
+=head2 $task->is_running()
+
+Get status on whether a task is running or not. Returns 1 if running, empty
+string if not.
+
 =head1 BUGS
 
 Any in libgearman plus many others of my own.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2009 Dennis Schoen
+Copyright (C) 2009-2010 Dennis Schoen
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.9 or,
@@ -61,10 +83,13 @@ at your option, any later version of Perl 5 you may have available.
 
 This is free software. IT COMES WITHOUT WARRANTY OF ANY KIND.
 
-=head1 AUTHORS
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=head1 AUTHOR
 
 Dennis Schoen <dennis@blogma.de>
 
-=cut
-
-1;
\ No newline at end of file
+=cut
\ No newline at end of file
